Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(391)

Unified Diff: webrtc/common_video/libyuv/include/webrtc_libyuv.h

Issue 2020593002: Refactor scaling. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Delete ShallowCenterCrop. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/common_video/libyuv/include/webrtc_libyuv.h
diff --git a/webrtc/common_video/libyuv/include/webrtc_libyuv.h b/webrtc/common_video/libyuv/include/webrtc_libyuv.h
index d66736fb248ea958de646c559ffd55c75d4f3fda..0d97241b6d660a46b2803c16e8cb0694f4b138cd 100644
--- a/webrtc/common_video/libyuv/include/webrtc_libyuv.h
+++ b/webrtc/common_video/libyuv/include/webrtc_libyuv.h
@@ -85,13 +85,17 @@ size_t CalcBufferSize(VideoType type, int width, int height);
// Return value: 0 if OK, < 0 otherwise.
int PrintVideoFrame(const VideoFrame& frame, FILE* file);
// Extract buffer from VideoFrame (consecutive planes, no stride)
// Input:
// - frame : Reference to video frame.
// - size : pointer to the size of the allocated buffer. If size is
// insufficient, an error will be returned.
// - buffer : Pointer to buffer
// Return value: length of buffer if OK, < 0 otherwise.
+int ExtractBuffer(const rtc::scoped_refptr<VideoFrameBuffer>& input_frame,
pbos-webrtc 2016/05/31 14:14:01 const VideoFrameBuffer& src
+ size_t size,
+ uint8_t* buffer);
int ExtractBuffer(const VideoFrame& input_frame, size_t size, uint8_t* buffer);
// Convert To I420
// Input:
@@ -85,13 +85,17 @@ size_t CalcBufferSize(VideoType type, int width, int height);
// Return value: 0 if OK, < 0 otherwise.
int PrintVideoFrame(const VideoFrame& frame, FILE* file);
-// Extract buffer from VideoFrame (consecutive planes, no stride)
+// Extract buffer from VideoFrame or VideoFrameBuffer (consecutive
+// planes, no stride)
// Input:
// - frame : Reference to video frame.

Powered by Google App Engine
This is Rietveld 408576698